@@ -1,11 +1,3 @@
-# Reexports models ------------------------
-
-#' @importFrom insight print_html
-#' @export
-insight::print_html
-
-
-#' @importFrom insight export_table
 #' @export
 print_html.describe_posterior <- function(x, digits = 2, caption = "Summary of Posterior Distribution", ...) {
   .print_html_default(x = x, digits = digits, caption = caption, ...)
@@ -129,7 +121,6 @@ print_html.bayesfactor_restricted <- function(x,
 
 #' @export
 print_html.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
@@ -154,7 +145,6 @@ print_html.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
 
 
 .print_html_default <- function(x, digits = 2, caption = NULL, subtitles = NULL, ci_string = "CI", ...) {
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
